==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/cnd.apt/src/org/netbeans/modules/cnd/apt/support/PostIncludeData.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2010 Sun Microsystems, Inc.
 */

package org.netbeans.modules.cnd.apt.support;

import org.netbeans.modules.cnd.apt.support.APTMacroMap.State;

/**
 * entry to store post include data
 * @author Vladimir Voskresensky
 */
public final class PostIncludeData {

    private final APTMacroMap.State postIncludeMacroState;
    private volatile int[]          deadBlocks;

    /*package*/ PostIncludeData() {
        // clean entry
        this.postIncludeMacroState = null;
        this.deadBlocks = null;
    }

    public PostIncludeData(State postIncludeMacroState, int[] deadBlocks) {
        this.postIncludeMacroState = postIncludeMacroState;
        this.deadBlocks = deadBlocks;
    }

    public State getPostIncludeMacroState() {
        return postIncludeMacroState;
    }

    public boolean hasPostIncludeMacroState() {
        return postIncludeMacroState != null;
    }

    public int[] getDeadBlocks() {
        // TODO: return copy?
        return deadBlocks;
    }

    public void setDeadBlocks(int[] deadBlocks) {
        // TODO: make a copy?
        this.deadBlocks = deadBlocks;
    }

    public boolean hasDeadBlocks() {
        return deadBlocks != null;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        if (deadBlocks == null) {
            sb.append("null"); // NOI18N
        } else {
            sb.append("[");//NOI18N
            for (int i = 0; i < deadBlocks.length; i += 2) {
                if (i > 0) {
                    sb.append("][");//NOI18N
                }
                sb.append(deadBlocks[i]);
                sb.append("-");//NOI18N
                sb.append(deadBlocks[i + 1]);
            }
            sb.append("]");//NOI18N
        }
        sb.append("\n state {").append(postIncludeMacroState).append("}"); // NOI18N
        return sb.toString();
    }

}

==> netbeans_8.1+dfsg3.orig.tar.xz: netbeans-8.1/cnd.apt/src/org/netbeans/modules/cnd/apt/support/PostIncludeData.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2010 Sun Microsystems, Inc.
 */

package org.netbeans.modules.cnd.apt.support;

import org.netbeans.modules.cnd.apt.support.api.PPMacroMap.State;

/**
 * entry to store post include data
 * @author Vladimir Voskresensky
 */
public final class PostIncludeData {

    private final APTMacroMap.State postIncludeMacroState;
    private volatile int[]          deadBlocks;

    /*package*/ PostIncludeData() {
        // clean entry
        this.postIncludeMacroState = null;
        this.deadBlocks = null;
    }

    public PostIncludeData(State postIncludeMacroState, int[] deadBlocks) {
        this.postIncludeMacroState = postIncludeMacroState;
        this.deadBlocks = deadBlocks;
    }

    public State getPostIncludeMacroState() {
        return postIncludeMacroState;
    }

    public boolean hasPostIncludeMacroState() {
        return postIncludeMacroState != null;
    }

    public int[] getDeadBlocks() {
        // TODO: return copy?
        return deadBlocks;
    }

    public void setDeadBlocks(int[] deadBlocks) {
        // TODO: make a copy?
        this.deadBlocks = deadBlocks;
    }

    public boolean hasDeadBlocks() {
        return deadBlocks != null;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        if (deadBlocks == null) {
            sb.append("null"); // NOI18N
        } else {
            sb.append("[");//NOI18N
            for (int i = 0; i < deadBlocks.length; i += 2) {
                if (i > 0) {
                    sb.append("][");//NOI18N
                }
                sb.append(deadBlocks[i]);
                sb.append("-");//NOI18N
                sb.append(deadBlocks[i + 1]);
            }
            sb.append("]");//NOI18N
        }
        sb.append("\n state {").append(postIncludeMacroState).append("}"); // NOI18N
        return sb.toString();
    }

}
